#!/bin/bash
#
# source: http://web.mit.edu/kerberos/dist/krb5/1.6/krb5-1.6.3-signed.tar
#
# packager: gmg (gerard.monpontet@orange.fr)
#

#------------------Set Some Variables

soft="krb5"
softversion="1.6.3"
packageversion="50.1"

arch="i486"
cpu="i686"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion/src"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
rm -f $dest.tgz
rm -rf $dest
tar -xvzf $srcpkg

mkdir -p $dest/install

#----------------- Make the slack-desc files

cat << EOF > $dest/install/slack-desc
         |-----handy-ruler------------------------------------------------------|
$soft: krb5 (is a MIT Kerberos network authentication protocol)
$soft:
$soft: Kerberos is a network authentication protocol. It is designed
$soft: to provide strong authentication for client/server applications
$soft: by using secret-key cryptography. A free implementation of this
$soft: protocol is available from MIT.
$soft:
$soft:
$soft:
$soft:
$soft:
EOF

#------------------Set correct permissions

chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#------------------Start Configure

cd $src

export CFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
    --prefix=/usr \
    --sysconfdir=/etc \
    --enable-shared

make
make install DESTDIR=$dest

#-----------------Copy the documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cd $buildir/$soft-$softversion
cp -r doc/* $dest/usr/doc/$soft-$softversion

mkdir -p $dest/usr/info
cp -a $dest/usr/doc/$soft-$softversion/krb5-*.info* $dest/usr/info
rm -f $dest/usr/doc/$soft-$softversion/krb5-*.info*
gzip -9 $dest/usr/info/*


#-----------------Strip executables 

(cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

find $dest/usr/man -type f -exec gzip -9 {} \;

chown -R root:root . $dest/usr/bin

#-----------------Put the ZenWalk build in the right directory

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#---------------- Add README in /usr/doc

cd $buildir/$soft-$softversion
cp -a README $dest/usr/doc/$soft-$softversion

#-----------------Make the packages and the md5sum
cd $dest
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.tgz >$package.md5
